==> whmcs-8.6.2-release.1.zip: modules/gateways/stripe/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.6.2 (8.6.2-release.1)                                      *
// * BuildId:b8a9b70.304                                                  *
// * Build Date:14 Jun 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPqO12VdExF7+vxASsdx7qoTo4Fv7iyJIn878IWr62tgO5dr7wDn/GMru8a6Vm2+rK7l8qcdB
5Fs/TgnVP4jRIqxbkdsDR/LXEhyp/8wEcqoRPykgEe4tEb4XwDXazngIjjRRoXz9AQ/tFRIJmwSt
yGzsRECIdN344XwsOa9/xXCjhf+Mo7J0ONmHM1JL/ugCNHi07x7ZwJPmZeO9G3DR7AamowOeveEX
ahSVGm5Zst+9vLpDV2fjgU+z2BGhfbkm5o7hIHT61dM9OeBu+0QZx+nGRYPCZrcOxHQZ5sC2GNe0
MqSpRrp05hq0EAqgxdzoiNSpL+aLojXvHLpgyUrLXyPxVIjgcQX4DPzfpvnID/01PYiSLHoci465
eNweUmCsAdei+G2ivVSsTdT70WPf7QpNED4vtrFMVVl6yjh5BguZ6gNXvS8CMS9UdrxjrKWX8iwV
jrwSZTeiQI9fbQtqOB2qgfsSTTdzitf92tM721fweS7DBH0qww/PzkW2z2B6Uab/odA7Q1VRDXS4
JXUkWhO9DTLDTgcPbTQEBaUy/uGE7837w4CfY2HNNtj9ni2cVtAibGCdRAWr3Q0RjSZKE0zuQ1mv
Z4MIFqNZ2eAtcadK29/Gma3L9z9rgp5chfTIEnMyxpi3CfhNc8UICvrGaFOdSj1uky1lIZB8LBVS
4wBVgHkaMBiDUtcQB5CcGqBFj7qUDMTleRUBRnyXCwp7XdVYwpqlJQ+KlrmTP4ytP8bXyBwn63ix
UW0ZPPZ5XyTQp0F7Z+XSLE+K3Qzzw4OErwML49173wmrkcD5jMoJ0VlrsT+CLobwXet/pqk2yXlQ
C+NHUIJa17fpTz9mLSn5xZ2dRixecW8pV74ja12mG3JYnAaaAQ7hCLLdohnhphpW=
HR+cPvQt5BNyXUswYGc1bgqHhfajYv/ElonzXyvW7cLGKw95oIOODmtGbVzBFXU9pDU8upGhPu/w
/khcx3zZWYhRtVLGJvmlDIKRh5TJk8/Vg0dQcv9zPirhL/QH9HMUP5jn76v5vpffFyxC+22BMWhs
+68dC49bASENI28mrZrr2cgg7piV6bhTqi7Te+i2BiivdwZo4ynDsZubO8UIIrqQKoNgYIV7qd6z
6B76Dv7Jb9n4eFSgcQng6+xUvGbhTiabbnawRsU37q3wBlLGVXt1HowOG6I2b+oXM/VkE7E9gfpM
ou520birSERSFKtArDmgULZ8v2NRF/yKr5vPvRmK8hE3qjHD7nj34QKFWc8hVsWuf/x2on7rySTM
xX5jjKcTzDnPabBIWildqcV7yQc68VHx5N5bYa4kGb45+dFmM2yCJ5OMkhZjRCTGGkCLy70bqzcH
b9B9HjasV29kOYEh+R9oJ+yw9wEbxCPDQa4fnc7jJXMdpcszjTYPYUczhnQRg/ZxP2X5QMNfiF6o
45++UefartTUmlIvZn0dIgyvR4jO0CLnriTKCBVtv302zomXeeHqWvcdu7eGmUTvYcAENADXxrFv
cdNRaM9D2VaXRcbQ44ln4BAChKR+fxnGQAWaxtQQY9oxXMS0naiRmdL/ZjxggalwIcPbdtVR8Qhq
lbKW9OQBgwqLh/f6Y6JXtTiOspVp01JwmpFxtw8uNRuUZXHA/Ydgv4xJOiwHrC0zI/ybYa5/+cCI
qFxJbnymzt5lkEtPZH5wwn61xTVHQwHmbfgvxHLYWIIOPs4hH4OtaqFXtfAkylDzZFw7m/OaTyBC
t1WZzazNhwjuqHWztHuIFcaxiAxhCe8nFz7/ABl479Wek6XKMr90wh9PstAP

==> whmcs-8.7.2-release.1.zip: modules/gateways/stripe/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.7.2 (8.7.2-release.1)                                      *
// * BuildId:5e9b2f1.301                                                  *
// * Build Date:25 Apr 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPxAoGZ+RdBSm4W7N73l+9m5DAx5MWwcx6TS++r2ERQ/cidVKuqfXEK0XYkMiyPBX6h1zvo5I
jKdfx9VE7fNsMsxeGXHRfYAK9qDRt5f8Iq/+q3b1HB4ZjOksYUvtKcDUK1hioiBVJyPMzu2fS9Gn
BmKv9LbxdrwI5pl9hMN/ZdAQ1B5jFGuw/CM713kgToPQ/v6um33CJfWaeABUQBWfJ54TQp5G1mZ6
KgkUUYXUcjF541pSwNqClf+0tKlAOvZC3WCXS8SQYNqp+HAD33N0M8CUdXZBqSGUlX8KeYaKT9rZ
651K4Mh3zo9tnmC2+BfgupTMfo+R/TIeKt1gCcA0Pk/RodhC4V6Nf18IO8/B3mpEr4S+rybxzsyA
baTPzKM3ZcxavwIipI+U55qZrrAKtSL9UKcQAU8C0cBVZ3UIYbDXnKuTT/nlpWT32XTQSP0AwRfC
2azwlqAeReTI5JCorINy8sAnWi5luqiDtzGO9fKcXPxB3n/rY3/aP+vMWRRU9ln4HR0qNbyIlZsZ
aGpBLpgFDKDZhZhlRp6OxuOjqj7ZukjEuWyn7UMjg7ZvIfuc/vpFVPGDglcDstqQ6bWDLb3iVzZF
zTVI1t8mMzbiOE4Ah5ukbPdqp3g6Mx6Uwk2mPPlNzJ9Y6+VejVLq9BiS0L5JBhispccTSg2u06JI
Dh6xAHP0K99zw2lkv/Ga8FVQR4cSr92lNXJr7UGCM8/7SYpXX4iCk9pLNZaEZjKAa/Kc70afzA5l
RxtnLRzrHP62XWq2mqBxlbYqFw6kk9/+gRzRaM9YK4K99yhXQANJvOBTFjRuEo1mW7KhaarMMgE3
Jyqo9RvMWf3xonBUetwfOZ62pbZZ+Umc74+HoGCargHceguS6n/Ob2C7kw7IR9G==
HR+cPxxk+mi5Gi0ie51kADgkyzc9dUJexC4l2xB8Hom9DcR0WnWFxqC9M/z3XFwEnqgN1lzXGklI
PIwguKSZ7+oAA/P380YJ3tuzpgAIgEtyjZrV5/FwqjaVHRLXhZ+UY8pV9oVXKgXZsfsksRw+Zp7i
DQ2/NWKIvpFyd5WgsZDhKelAMnDwrGYwBaIYxT4LM0hDYzbLm8ftWUGvGF90G4gzYHq5flDBJOme
ZbR4uj/xszDg/i1lMAkoKiHzH/zmKuAfbtlncoNFzWHpNWZg2dxHx6hPV02MP5091PFFMUNsI+PV
NrBNT16kAE2o3WvCPxUP99WdHF+s7RB8je0wciFKBXPe4vwty3+xIipX8Z+sJB4ojonkqfk+PGLf
zUHr9uX0NAjWBvWZbHv0Db6LACyHRg17/zE/EORQv1ndnP8ieOlPmMdhSPMu89g10r7wJjS6XiIx
abg4fjjtZ+uhUGPsxk4jEHb5ouhurHdqh/CX2ujDT5FJr7uBgDG+ozsnnGvaYLE/j3rnqL0pDVcU
euHUKCeAeHyIstb+rVx1RFhOYk91fkFV8hByKScW17O+rCo2K/hRB0a14Ty6PELcVk2qtYPmRRDK
6MLs2oP3bsNNKbsk03CEbdCDwlsg2rYXkGfW5zkeyExixZydGfT1HLAgK3zUJD0Pe3MdeZzIZlfM
NPuP2zZUaTNKewowAIDkIAEVlTNpQJ+T0yiG6C/SDdqNsVciTKb5tSEWB4XH+UNBedpQIGBwNVwO
QEK+GdwNDr6KVuukp5ZCH2fvN6gH7URcono58N+XbGAkXn3aaMazsGILmfeNwchxvkAC21zyGt7L
3HswiVQwRTkkhyc0orN8ZJQPuWcMkfkax8CTMcHGOtXaI1n+ccMXPjJ/1tS=
